@@ -9,7 +9,7 @@ use base qw/
 use NEXT;
 use Cache::FileCache ();
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 __PACKAGE__->mk_classdata(qw/_session_file_storage/);
 
@@ -23,7 +23,6 @@ session data.
 	use Catalyst qw/Session Session::Store::File Session::State::Foo/;
 
 	MyApp->config->{session} = {
-		expires => 3600,
 		storage => '/tmp/session'
 	};
 
@@ -68,10 +67,7 @@ sub delete_session_data {
     $c->_session_file_storage->remove($sid);
 }
 
-sub delete_expired_sessions {
-    my ($c) = @_;
-    $c->_session_file_storage->purge();
-}
+sub delete_expired_sessions { }
 
 =item setup_session
 
@@ -98,7 +94,6 @@ sub setup_session {
         Cache::FileCache->new(
             {
                 cache_root  => $cfg->{storage},
-                expire_time => $cfg->{expires},
                 (
                     map { $_ => $cfg->{$_} }
                       grep { exists $cfg->{$_} }
@@ -133,12 +128,12 @@ UID of the process in the filename.
 
 =item relative
 
-Makes the storage path relative to I< $c->path_to >
+Makes the storage path relative to I<$c->path_to>
 
 =item namespace
 
 The namespace associated with this cache. Defaults to an empty string if not explicitly set.
-If set, the session data will be stored in a directory called C< MyApp/session/data/<namespace> >.
+If set, the session data will be stored in a directory called C<MyApp/session/data/<namespace>>.
 
 =item cache_depth
 
